# Semantido

[![PyPI - Version](https://img.shields.io/pypi/v/semantido.svg)](https://pypi.org/project/semantido)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/semantido.svg)](https://pypi.org/project/semantido)

-----

Table of Contents
-----

- [About](#about)
- [Installation](#installation)
- [Contributing](#contributing)
- [License](#license)

About
-----
In the world of GenAI, providing a reliable semantic layer foundations for a reliable RAG and agentic systems becomes the real differentiator. 
The value is in your data and workflows. `semantido` handles the semantic layer plumbing so you can focus on what makes your system unique.

-----

```console
pip install semantido
```

Contributing
-----
Contributions to this library are welcomed and highly encouraged.
See [CONTRIBUTING.md](https://github.com/hikarilabs/semantido/blob/main/CONTRIBUTING.md) for more information on how to get started.

License
-----
`semantido` is distributed under the terms of the [Apache License 2.0](https://spdx.org/licenses/Apache-2.0.html) license.
